@@ -1,11 +1,14 @@
+from __future__ import annotations
+
 import mmap
 import os
+from collections.abc import Iterator
 from urllib.parse import quote, unquote
 
-from .common import ZictBase
+from zict.common import ZictBase
 
 
-def _safe_key(key):
+def _safe_key(key: str) -> str:
     """
     Escape key so as to be usable on all filesystems.
     """
@@ -13,14 +16,14 @@ def _safe_key(key):
     return quote(key, safe="")
 
 
-def _unsafe_key(key):
+def _unsafe_key(key: str) -> str:
     """
     Undo the escaping done by _safe_key().
     """
     return unquote(key)
 
 
-class File(ZictBase):
+class File(ZictBase[str, bytes]):
     """Mutable Mapping interface to a directory
 
     Keys must be strings, values must be bytes
@@ -51,7 +54,12 @@ class File(ZictBase):
     >>> z['data'] = np.ones(5).data  # doctest: +SKIP
     """
 
-    def __init__(self, directory, mode="a", memmap=False):
+    directory: str
+    mode: str
+    memmap: bool
+    _keys: set[str]
+
+    def __init__(self, directory: str, mode: str = "a", memmap: bool = False):
         self.directory = directory
         self.mode = mode
         self.memmap = memmap
@@ -62,16 +70,12 @@ class File(ZictBase):
             for n in os.listdir(self.directory):
                 self._keys.add(_unsafe_key(n))
 
-    def __str__(self):
-        return '<File: %s, mode="%s", %d elements>' % (
-            self.directory,
-            self.mode,
-            len(self),
-        )
+    def __str__(self) -> str:
+        return f'<File: {self.directory}, mode="{self.mode}", {len(self)} elements>'
 
     __repr__ = __str__
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: str) -> bytes:
         if key not in self._keys:
             raise KeyError(key)
         fn = os.path.join(self.directory, _safe_key(key))
@@ -81,7 +85,16 @@ class File(ZictBase):
             else:
                 return fh.read()
 
-    def __setitem__(self, key, value):
+    def __setitem__(
+        self,
+        key: str,
+        value: bytes
+        | bytearray
+        | list[bytes]
+        | list[bytearray]
+        | tuple[bytes]
+        | tuple[bytearray],
+    ) -> None:
         fn = os.path.join(self.directory, _safe_key(key))
         with open(fn, "wb") as fh:
             if isinstance(value, (tuple, list)):
@@ -90,19 +103,21 @@ class File(ZictBase):
                 fh.write(value)
         self._keys.add(key)
 
-    def __contains__(self, key):
+    def __contains__(self, key: object) -> bool:
         return key in self._keys
 
-    def keys(self):
+    # FIXME dictionary views https://github.com/dask/zict/issues/61
+    def keys(self) -> set[str]:  # type: ignore
+        return self._keys
+
+    def __iter__(self) -> Iterator[str]:
         return iter(self._keys)
 
-    __iter__ = keys
-
-    def __delitem__(self, key):
+    def __delitem__(self, key: str) -> None:
         if key not in self._keys:
             raise KeyError(key)
         os.remove(os.path.join(self.directory, _safe_key(key)))
         self._keys.remove(key)
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self._keys)
